@@ -59,6 +59,7 @@ class ConnectionTestException(Exception):
         BASE64_ENCODE = "base64_encode"
         BASE64_DECODE = "base64_decode"
         TIMEOUT = "timeout"
+        BAD_REQUEST = "bad_request"
     # Dictionary of cause messages
     causes = {
         Preset.API_KEY: "Invalid API key provided.",
@@ -73,6 +74,7 @@ class ConnectionTestException(Exception):
         Preset.BASE64_ENCODE: "Unable to base64 encode content due to incorrect padding length.",
         Preset.BASE64_DECODE: "Unable to base64 decode content due to incorrect padding length.",
         Preset.TIMEOUT: "The connection timed out.",
+        Preset.BAD_REQUEST: "The server is unable to process the request.",
     }
 
     # Dictionary of assistance/remediation messages
@@ -92,6 +94,8 @@ class ConnectionTestException(Exception):
         Preset.BASE64_DECODE: "This is likely a programming error, if the issue persists please contact support.",
         Preset.TIMEOUT: "This is likely a network error. "
                         "Verify the network activity. If the issue persists, please contact support.",
+        Preset.BAD_REQUEST: "Verify your plugin input is correct and not malformed and try again. "
+                            "If the issue persists, please contact support.",
     }
 
     def __init__(self, cause=None, assistance=None, data=None, preset=None):
